from setuptools import setup

setup(name='gusbidis_calculation',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['gusbidis_calculation'],
      author = 'Christabel Ajaero',
      author_email = 'ajaero.christabel@gmail.com',
    zip_safe=False)
